@@ -1,3 +1,5 @@
+from dataverk.utils.file_functions import remove_special_characters
+
 from dataverk.utils import file_functions
 
 from dataverk.resources.base_resource import BaseResource
@@ -19,11 +21,10 @@ class JSONResource(BaseResource):
         self._schema = self._get_schema()
 
     def formatted_resource_name(self):
-        return file_functions.url_encode(self._resource_name)
+        return remove_special_characters(self._resource_name)
 
     def _resource_path(self):
         return self._create_resource_path(
-            self._datapackage_path,
             self.formatted_resource_name(),
             self._fmt,
             False
@@ -31,7 +32,7 @@ class JSONResource(BaseResource):
 
     def _get_schema(self):
         return {
-            "name": self.formatted_resource_name(),
+            "name": self._resource_name,
             "description": self._resource_description,
             "path": self._resource_path(),
             "format": self._fmt,
