@@ -1,9 +1,9 @@
+from abc import ABC
 from typing import Sequence
-from dataverk.utils import file_functions
 from dataverk.views.base import BaseView
 
 
-class RemoteSpecView(BaseView):
+class RemoteSpecView(ABC, BaseView):
 
     def __init__(self, name: str, resources: Sequence, title: str = "", description: str = "", attribution: str = "",
                  spec_type: str = "simple", spec: dict = None, type: str = "", group: str = "",
@@ -13,13 +13,9 @@ class RemoteSpecView(BaseView):
                          series=series, row_limit=row_limit, metadata=metadata)
 
     def add_to_datapackage(self, dp):
-        resource_path = dp.add_resource(self._spec,
-                                        resource_name=file_functions.url_encode(self._name),
-                                        resource_description=self._name,
-                                        resource_type="json",
-                                        spec={'hidden': True})
+        resource_path = self._add_resource(dp)
         dp.datapackage_metadata["views"].append({
-            'name': file_functions.url_encode(self._name),
+            'name': self._name,
             'title': self._title,
             'description': self._description,
             'attribution': self._attribution,
@@ -33,3 +29,6 @@ class RemoteSpecView(BaseView):
             },
             'metadata': self._metadata
         })
+
+    def _add_resource(self, dp):
+        raise NotImplementedError()
